==> async-invoker-0.0.1.tgz: package/lib/async.invoker.js <==
(function() {
  var AsyncInvoker, Promise, _, eval_,
    bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
    slice = [].slice;

  Promise = require("bluebird");

  eval_ = require("eval");

  _ = require("lodash");

  module.exports = AsyncInvoker = (function() {
    function AsyncInvoker(code, options, globals) {
      this.options = options != null ? options : {};
      if (globals == null) {
        globals = {};
      }
      this._assertIsFunction = bind(this._assertIsFunction, this);
      this._tryTo = bind(this._tryTo, this);
      this.run = bind(this.run, this);
      _.defaults(this.options, {
        logErrors: true
      });
      code = "module.exports = " + code;
      this._run = this._tryTo(((function(_this) {
        return function() {
          return eval_(code, globals);
        };
      })(this)), "has compile errors");
      this._assertIsFunction(this._run);
    }

    AsyncInvoker.prototype.run = function() {
      var args, tryLog, tryRun;
      args = 1 <= arguments.length ? slice.call(arguments, 0) : [];
      tryRun = (function(_this) {
        return function(functionArgs) {
          return _this._tryTo((function() {
            return _this._run.apply(null, functionArgs);
          }), "exploded");
        };
      })(this);
      tryLog = (function(_this) {
        return function(e) {
          if (_this.options.logErrors) {
            return console.log(e);
          }
        };
      })(this);
      return new Promise((function(_this) {
        return function(resolve, reject) {
          var e, error, output;
          try {
            output = tryRun(args.concat(resolve));
            if (!_.isUndefined(output)) {
              return resolve(output);
            }
          } catch (error) {
            e = error;
            tryLog(e);
            return reject(e);
          }
        };
      })(this));
    };

    AsyncInvoker.prototype._tryTo = function(doSomething, errorMessage) {
      var e, error;
      try {
        return doSomething();
      } catch (error) {
        e = error;
        throw new Error("The function " + (errorMessage || e) + ": " + e.message);
      }
    };

    AsyncInvoker.prototype._assertIsFunction = function(func) {
      if (!_.isFunction(func)) {
        throw new Error("The function is not a function");
      }
    };

    return AsyncInvoker;

  })();

}).call(this);

==> async-invoker-1.0.0.tgz: package/lib/async.invoker.js <==
(function() {
  var AsyncInvoker, Promise, _, eval_,
    bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
    slice = [].slice;

  Promise = require("bluebird");

  eval_ = require("eval");

  _ = require("lodash");

  module.exports = AsyncInvoker = (function() {
    function AsyncInvoker(code, options, globals) {
      this.options = options != null ? options : {};
      if (globals == null) {
        globals = {};
      }
      this._assertIsFunction = bind(this._assertIsFunction, this);
      this._tryTo = bind(this._tryTo, this);
      this.invoke = bind(this.invoke, this);
      _.defaults(this.options, {
        logErrors: true
      });
      code = "module.exports = " + code;
      this._invoke = this._tryTo(((function(_this) {
        return function() {
          return eval_(code, globals);
        };
      })(this)), "has compile errors");
      this._assertIsFunction(this._invoke);
    }

    AsyncInvoker.prototype.invoke = function() {
      var args, tryInvoke, tryLog;
      args = 1 <= arguments.length ? slice.call(arguments, 0) : [];
      tryInvoke = (function(_this) {
        return function(functionArgs) {
          return _this._tryTo((function() {
            return _this._invoke.apply(null, functionArgs);
          }), "exploded");
        };
      })(this);
      tryLog = (function(_this) {
        return function(e) {
          if (_this.options.logErrors) {
            return console.log(e);
          }
        };
      })(this);
      return new Promise((function(_this) {
        return function(resolve, reject) {
          var e, error, output;
          try {
            output = tryInvoke(args.concat(resolve));
            if (!_.isUndefined(output)) {
              return resolve(output);
            }
          } catch (error) {
            e = error;
            tryLog(e);
            return reject(e);
          }
        };
      })(this));
    };

    AsyncInvoker.prototype._tryTo = function(doSomething, errorMessage) {
      var e, error;
      try {
        return doSomething();
      } catch (error) {
        e = error;
        throw new Error("The function " + (errorMessage || e) + ": " + e.message);
      }
    };

    AsyncInvoker.prototype._assertIsFunction = function(func) {
      if (!_.isFunction(func)) {
        throw new Error("The function is not a function");
      }
    };

    return AsyncInvoker;

  })();

}).call(this);
